Ricecooker utils
================
The ``ricecooker.utils`` module includes a number of utility functions to help
chef authors with common content extraction and transformation tasks.

.. toctree::
   :maxdepth: 1


   downloader
   parsing_html
   developer/kolibripreview
   pdfutils
   video_compression
   csv_metadata/index
